summaryrefslogtreecommitdiff
path: root/basic/source/inc/scanner.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'basic/source/inc/scanner.hxx')
-rwxr-xr-x[-rw-r--r--]basic/source/inc/scanner.hxx54
1 files changed, 27 insertions, 27 deletions
diff --git a/basic/source/inc/scanner.hxx b/basic/source/inc/scanner.hxx
index aa9aa82086..684148f840 100644..100755
--- a/basic/source/inc/scanner.hxx
+++ b/basic/source/inc/scanner.hxx
@@ -57,33 +57,33 @@ protected:
short nCol; // aktuelle Spaltennummer
short nErrors; // Anzahl Fehler
short nColLock; // Lock-Zaehler fuer Col1
- INT32 nBufPos; // aktuelle Buffer-Pos
- USHORT nLine; // aktuelle Zeile
- USHORT nCol1, nCol2; // aktuelle 1. und 2. Spalte
- BOOL bSymbol; // TRUE: Symbol gescannt
- BOOL bNumber; // TRUE: Zahl gescannt
- BOOL bSpaces; // TRUE: Whitespace vor Token
- BOOL bErrors; // TRUE: Fehler generieren
- BOOL bAbort; // TRUE: abbrechen
- BOOL bHash; // TRUE: # eingelesen
- BOOL bError; // TRUE: Fehler generieren
- BOOL bUsedForHilite; // TRUE: Nutzung fuer Highlighting
- BOOL bCompatible; // TRUE: OPTION Compatibl
- BOOL bVBASupportOn; // TRUE: OPTION VBASupport 1 otherwise default False
- BOOL bPrevLineExtentsComment; // TRUE: Previous line is comment and ends on "... _"
+ sal_Int32 nBufPos; // aktuelle Buffer-Pos
+ sal_uInt16 nLine; // aktuelle Zeile
+ sal_uInt16 nCol1, nCol2; // aktuelle 1. und 2. Spalte
+ sal_Bool bSymbol; // sal_True: Symbol gescannt
+ sal_Bool bNumber; // sal_True: Zahl gescannt
+ sal_Bool bSpaces; // sal_True: Whitespace vor Token
+ sal_Bool bErrors; // sal_True: Fehler generieren
+ sal_Bool bAbort; // sal_True: abbrechen
+ sal_Bool bHash; // sal_True: # eingelesen
+ sal_Bool bError; // sal_True: Fehler generieren
+ sal_Bool bUsedForHilite; // sal_True: Nutzung fuer Highlighting
+ sal_Bool bCompatible; // sal_True: OPTION Compatibl
+ sal_Bool bVBASupportOn; // sal_True: OPTION VBASupport 1 otherwise default False
+ sal_Bool bPrevLineExtentsComment; // sal_True: Previous line is comment and ends on "... _"
void GenError( SbError );
public:
SbiScanner( const ::rtl::OUString&, StarBASIC* = NULL );
~SbiScanner();
- void EnableErrors() { bError = FALSE; }
- BOOL IsHash() { return bHash; }
- BOOL IsCompatible() { return bCompatible; }
+ void EnableErrors() { bError = sal_False; }
+ sal_Bool IsHash() { return bHash; }
+ sal_Bool IsCompatible() { return bCompatible; }
void SetCompatible( bool b ) { bCompatible = b; } // #118206
- BOOL IsVBASupportOn() { return bVBASupportOn; }
+ sal_Bool IsVBASupportOn() { return bVBASupportOn; }
void SetVBASupportOn( bool b ) { bVBASupportOn = b; }
- BOOL WhiteSpace() { return bSpaces; }
+ sal_Bool WhiteSpace() { return bSpaces; }
short GetErrors() { return nErrors; }
short GetLine() { return nLine; }
short GetCol1() { return nCol1; }
@@ -94,9 +94,9 @@ public:
void RestoreLine(void) { pLine = pSaveLine; }
void LockColumn();
void UnlockColumn();
- BOOL DoesColonFollow();
+ sal_Bool DoesColonFollow();
- BOOL NextSym(); // naechstes Symbol lesen
+ sal_Bool NextSym(); // naechstes Symbol lesen
const String& GetSym() { return aSym; }
SbxDataType GetType() { return eScanType; }
double GetDbl() { return nVal; }
@@ -122,22 +122,22 @@ class BasicSimpleCharClass
static LetterTable aLetterTable;
public:
- static BOOL isAlpha( sal_Unicode c, bool bCompatible )
+ static sal_Bool isAlpha( sal_Unicode c, bool bCompatible )
{
- BOOL bRet = (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z')
+ sal_Bool bRet = (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z')
|| (bCompatible && aLetterTable.isLetter( c ));
return bRet;
}
- static BOOL isDigit( sal_Unicode c )
+ static sal_Bool isDigit( sal_Unicode c )
{
- BOOL bRet = (c >= '0' && c <= '9');
+ sal_Bool bRet = (c >= '0' && c <= '9');
return bRet;
}
- static BOOL isAlphaNumeric( sal_Unicode c, bool bCompatible )
+ static sal_Bool isAlphaNumeric( sal_Unicode c, bool bCompatible )
{
- BOOL bRet = isDigit( c ) || isAlpha( c, bCompatible );
+ sal_Bool bRet = isDigit( c ) || isAlpha( c, bCompatible );
return bRet;
}
};